@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2024 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,8 @@ typedef enum
 {
 	FOLDER_SEL_ALL,
 	FOLDER_SEL_MOVE,
-	FOLDER_SEL_COPY
+	FOLDER_SEL_COPY,
+	FOLDER_SEL_SAVE
 } FolderSelectionType;
 
 FolderItem *foldersel_folder_sel(Folder			*cur_folder,
